# -*- coding: utf-8 -*-
from odoo import models, fields, api
from odoo.tools.translate import _
import logging

class cs_car(models.Model):
    _name = 'fleet.vehicle'
    _inherit = 'fleet.vehicle'

    battery_fee = fields.Selection([
        ('rent', _("Lloguer")),
        ('bougth', _("Compra")),
        ('no-quota', _("Sense Quota"))
    ], string=_("Bateria propietat"), default="rent")
    car_type = fields.Selection([
        ('fp', _("FP")),
        ('renting', _("Renting")),
        ('cic', _("CiC")),
        ('p2p', _("P2P")),
    ], string=_("Modalitat"), default="fp")
    bougth_km = fields.Integer(string=_("Km a la compra"))
    bougth_date = fields.Date(
        string=_("Data de compra"),
        related="purchase_invoice_id.date_invoice",
    )
    r_link_update = fields.Boolean(string=_("R-Link update"))
    key_number = fields.Char(string=_("Núm clau"))
    insurance_company = fields.Char(string=_("Asseguradora"))
    insurance_age = fields.Char(string=_("Edat assegurança"))
    insurance_policy = fields.Char(string=_("Polissa assegurança"))
    insurance_expiricy = fields.Date(string=_("Venciment Assegurança"))
    insurance_extras = fields.Text(string=_("Garanties Extres"))
    battery_size = fields.Integer(string=_("Tamany de la bateria"))
    next_tech_revision = fields.Date(string=_("Propera ITV"))
    next_revision = fields.Date(string=_("Propera revisió"))
    viat_applies = fields.Boolean(string=_("Aplica Via-T"))
    viat_pan = fields.Char(string=_("PAN Via-T"))
    viat_expiricy = fields.Date(string=_("Caducitat Via-T"))
    viat_onplace = fields.Boolean(string=_("Via-T col.locat?"))
    viat_eco_accepted = fields.Boolean(string=_("Eco Via-T acceptat?"))
    viat_eco_approved_date = fields.Date(string=_("Data aprovació Eco Via-T"))
    ivtm_status = fields.Selection([
        ('no', _("No")),
        ('no_apply', _("No aplica")),
        ('presented', _("Instància presentada")),
        ('yes', _("IVTM BONIFICAT"))
    ], string=_("Tramitada bonificació IVTM"), default="no")
    live_card = fields.Char(string=_("Targeta Live"))
    live_card_status = fields.Char(string=_("Estat Targeta Live"))
    live_smou = fields.Char(string=_("Live a SMOU"))
    electromaps_code = fields.Char(string=_("Codi electromaps"))
    garagekey_code = fields.Char(string=_("Mando garatge"))
    secondary_key_location = fields.Char(string=_("Ubicacio segona clau"))
    battery_rental = fields.Float(_("Quota bateria (sense IVA)"))
    contact_person_txt = fields.Char(string=_("Contacte"))
    vinyl = fields.Char(string=_("Vinil"))
    origin = fields.Char(string=_("Origen"))
    drive_docs = fields.Char(string=_("Documentació DRIVE"))
    has_gps = fields.Boolean(string=_("Has GPS?"))


    ## NEW FIELDS ##
    
    # Dades Vehicle

    sm_version = fields.Char(string=_("Versió"))
    tire_type = fields.Char(string=_("Mida rodes"))
    vehicle_license = fields.Char(string=_("Permís circulació"))
    technical_data = fields.Char(string=_("Fitxa tècnica"))
    ownership = fields.Selection([
            ('owned', 'Owned'),
            ('lesed', 'Lessed'),
            ('rented', 'Rented'),
            ('customer', 'Customer')
        ],
        string="Propietat",
    )
    app_service = fields.Boolean(
        string=_("App Service")
    )

    # Dades Compra

    partner_id = fields.Many2one(
        'res.partner',
        string=_("Proveïdor/Concessionàri")
    )
    purchase_invoice_id = fields.Many2one(
        'account.invoice',
        string=_("Factura")
    )
    currency_id = fields.Many2one(
        'res.currency',
        related="purchase_invoice_id.currency_id",
    )
    bought_price = fields.Monetary(
        string="Preu de compra",
        readonly=True,
        related="purchase_invoice_id.amount_total"
    )
    financing = fields.Boolean(string="Finançament")
    account_loan_id = fields.Many2one(
      'account.loan',
      string="Préstec"
    )
    financing_end_finish = fields.Date(
      string="Data Finalització finançament"
    )
    financing_contract = fields.Char(
      string="Contracte de finançament"
    )

    # Dades Venda

    date_change_name = fields.Date()
    sale_invoice_id = fields.Many2one(
        'account.invoice',
        string="Factura"
    )
    sale_date = fields.Date(
        string="Data Venda",
        related="sale_invoice_id.date_invoice",
        readonly=True,
    )
    sale_price = fields.Monetary(
        string="Preu Venda",
        related="sale_invoice_id.amount_total",
        readonly=True,
    )
    sale_partner_id = fields.Many2one(
        'res.partner',
        string="Nom comprador",
        related="sale_invoice_id.partner_id",
        readonly=True,
    )
    sale_phone = fields.Char(
        string="Telèfon",
        related="sale_partner_id.phone",
        readonly=True,
    )
    sale_mobile = fields.Char(
        string="Telèfon",
        related="sale_partner_id.mobile",
        readonly=True,
    )
    sale_email = fields.Char(
        string="Email",
        related="sale_partner_id.email",
        readonly=True,
    )

    # Altres

    barcelona_id_code = fields.Char(
        string=_("Codi identificatiu Barcelona"),
        related="live_card",
        store=True,
        readonly=False
    )


    # Modalitat Servei

    contracte_actiu = fields.Many2one(
        'contract.contract',
        string="Contracte actiu"
    )

    @api.multi
    @api.onchange('state_id')
    def _onchange_state_id(self):
        for vehicle in self:
            if vehicle.state_id:
                if vehicle.state_id.archived and vehicle.active:
                    vehicle.active = False
                elif not vehicle.state_id.archived and not vehicle.active:
                    vehicle.active = True

    # Dades Propietari
    owner_partner_id = fields.Many2one(
        'res.partner',
        string="Propietari"
    )
